"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
/**
 * Checks for scan input within a container and sends the output to a callback function.
 * @param param0 Config object
 */
var useScanDetection = function (_a) {
    var _b = _a.waitTime, waitTime = _b === void 0 ? 50 : _b, startCharacter = _a.startCharacter, _c = _a.endCharacter, endCharacter = _c === void 0 ? 13 : _c, onComplete = _a.onComplete, onError = _a.onError, _d = _a.minLength, minLength = _d === void 0 ? 1 : _d, ignoreIfFocusOn = _a.ignoreIfFocusOn, _e = _a.stopPropagation, stopPropagation = _e === void 0 ? false : _e, _f = _a.preventDefault, preventDefault = _f === void 0 ? false : _f, _g = _a.container, container = _g === void 0 ? document : _g;
    var buffer = react_1.useRef([]);
    var timeout = react_1.useRef(false);
    var clearBuffer = function () {
        buffer.current = [];
    };
    var onKeyDown = react_1.useCallback(function (event) {
        if (event.currentTarget !== ignoreIfFocusOn) {
            if (event.keyCode === endCharacter) {
                clearTimeout(timeout.current);
                if (buffer.current.length >= minLength) {
                    onComplete(buffer.current.slice(!!startCharacter ? 1 : 0).join(""));
                }
                else if (!!onError) {
                    onError("incomplete scan detected");
                }
                clearBuffer();
            }
            if (buffer.current.length > 0 || event.keyCode === startCharacter || !startCharacter) {
                clearTimeout(timeout.current);
                timeout.current = setTimeout(clearBuffer, waitTime);
                buffer.current.push(event.key);
            }
        }
        if (stopPropagation) {
            event.stopPropagation();
        }
        if (preventDefault) {
            event.preventDefault();
        }
    }, [
        startCharacter,
        endCharacter,
        waitTime,
        onComplete,
        onError,
        minLength,
        ignoreIfFocusOn,
        stopPropagation,
        preventDefault
    ]);
    react_1.useEffect(function () {
        return function () {
            clearTimeout(timeout.current);
        };
    }, []);
    react_1.useEffect(function () {
        container.addEventListener("keydown", (onKeyDown));
        return function () {
            container.removeEventListener("keydown", (onKeyDown));
        };
    }, [onKeyDown]);
};
exports.default = useScanDetection;
//# sourceMappingURL=index.js.map